@@ -877,13 +877,15 @@ class World:
     def __init__(self, name="PyBlockWorld"):
         self.window = Window(width=800, height=600, 
             caption=name, resizable=True)
-        self.window.unknown_key_pressed = self.__build_key_function
-        self.build_key_function = lambda world: print("b pressed")
+        self.window.unknown_key_pressed = self.__unknown_key_pressed
 
-    def __build_key_function(self, symbol):
+    def build_key_pressed(self):
+        pass
+
+    def __unknown_key_pressed(self, symbol):
         #print(symbol, "pressed")
         if symbol == key.B:
-            self.build_key_function(self)
+            self.build_key_pressed()
 
     def setBlock(self, x,y,z, blocktype):
         pos = int(x),int(y),int(z)
@@ -954,25 +956,29 @@ def setup():
 def main():
     from pyblockworld import World
 
-    # Eine Funktion, die beim Drücken der B-Taste aufgerufen werden soll
-    def b_key_pressed(world:World):
-        print("b pressed. player at", world.player_position())
-        x,y,z = world.player_position()
+    class MyWorld(World):
+        def __init__(self):
+            super().__init__()
 
-        # Neue Blöcke können mit setBlock gesetzt werden
-        # Verfügbare Materialien stehen in World.MATERIALS
-        print("Block types", World.MATERIALS)
-        world.setBlock(x,y,z, "default:brick")
+        # Eine Funktion, die beim Drücken der B-Taste aufgerufen werden soll
+        def build_key_pressed(world:World):
+            print("B pressed.")
+            x,y,z = world.player_position()
 
-        # Mehrere Blöcke auf einmal setzen
-        x,y,z = x,y,z+3
-        world.setBlocks(x,y,z, x+3,y+3,z+3, "default:brick")
+            # Neue Blöcke können mit setBlock gesetzt werden.
+            # Verfügbare Materialien stehen in World.MATERIALS und umfassen
+            # air, default:brick, default:stone, default:sand, default:grass
+            print("Block types", World.MATERIALS)
+            world.setBlock(x,y,z, "default:brick")
+
+            # Mehrere Blöcke auf einmal abseits des Spielers platzieren
+            x,y,z = x,y,z+3
+            world.setBlocks(x,y,z, x+3,y+3,z+3, "default:grass")
         
-    world = World("DEMO WORLD")
-    # Die Funktion für die build-Taste (b) wird zugewiesen
-    world.build_key_function = b_key_pressed
+    # Erstellen einer neuen Welt
+    my_world = MyWorld()
     # Die Welt wird gestartet
-    world.run()
+    my_world.run()
     
 
 if __name__ == '__main__':
